@@ -39,9 +39,9 @@ class DataApi:
             data = result['data']
             columns = data['fields']
             items = data['items']
-            return pd.DataFrame(items, columns=columns), data['total']
+            return pd.DataFrame(items, columns=columns), data['info']
         else:
-            return pd.DataFrame(), -1
+            return pd.DataFrame(), None
 
     def __getattr__(self, name):
         return partial(self.query, name)
